<?php

	

require_once('csendsms.inc.php');
  $sms = new CSendSMS();







////-------------->>>>>>BULK SMS AGENT  LITE---->>>>>>>>>>>>>>>>>>>>  
  
  $sms->Connect('smsmidlet_username','smsmidlet_password','password_for_smsagent_LITE'); //agent lite  

// example of long SMS (EMS), max 612 chars of text, smstype=10 , sender - my number +420606123456
$sms->AddSMS('420603123456','first sms text, first sms...','10','+420606123456');


//normal SMS, max 160 chars of text, smstype=1 , sender - my username
$sms->AddSMS('420603123456','Second sms text',1,'$uSeR_NaMe');

//FLASH, max 160 chars of text, smstype=2 , sender - my number +420606123456
$sms->AddSMS('420603123456','Third sms text',2,'+420606123456');


////-------------->>>>>>BULK SMS AGENT  LITE-----<<<<<<<<<<<<<<<<<<<<<<<<<<<<<





  $sms->SendAllSMS();
  $sms->Disconnect();
 print_r($sms->GetResults());






?>